@@ -1,6 +1,6 @@
 package Perl6::Pod::Directive::use;
 
-#$Id: use.pm 552 2009-06-01 18:26:08Z zag $
+#$Id: use.pm 572 2009-07-07 17:46:25Z zag $
 
 =pod
 
@@ -10,11 +10,33 @@ Perl6::Pod::Directive::use - handle =use directive
 
 =head1 SYNOPSIS
 
+Load the corresponding Perldoc module:
+
+    =use Test::Tag test2
+    =for test2
+    SOME data
+
+Define own formatting code:
+    
+    =use Perldoc::TT <TT>
+    =config TT<>  :allow<E>
+    head1 Overview of the M<TT: $CLASSNAME > class
+
 
 =head1 DESCRIPTION
 
 Perl6::Pod::Directive::use - handle =use directive
 
+Perldoc provides a mechanism by which you can extend the syntax, semantics, or content of your documentation: the =use directive.
+
+
+A =use directive may be specified with either a module name or a URI:
+
+    =use MODULE_NAME  OPTIONAL CONFIG DATA
+    =                 OPTIONAL EXTRA CONFIG DATA
+    
+    =use URI
+
 =cut
 
 use warnings;
