@@ -1,6 +1,6 @@
 package Perl6::Pod::Parser::ListLevels;
 
-#$Id$
+#$Id: ListLevels.pm 574 2009-07-13 03:57:29Z zag $
 
 =pod
 
@@ -27,10 +27,9 @@ use Data::Dumper;
 sub on_start_element {
     my ( $self, $el ) = @_;
     my $lname = $el->local_name;
-    return $el if $self->{IN_ITEM};
     my @res   = ($el);
     if ( $lname =~ /^item/ ) {
-        $self->{IN_ITEM}++;
+
         #item element
         unless ( $self->{IN_ITEMLIST}++ ) {
 
@@ -52,21 +51,13 @@ sub on_start_element {
 
     }
     else {
-        if ( delete  $self->{IN_ITEMLIST} ) {
+        if ( delete $self->{IN_ITEMLIST} ) {
             unshift @res, $self->mk_end_element( $self->mk_block('itemlist') );
         }
     }
     \@res;
 }
 
-sub on_end_element {
-    my ($self, $el) = @_;
-    my $lname = $el->local_name;
-    if ( $lname =~ /^item/ ) {
-           delete $self->{IN_ITEM};
-    }
-    return $el;
-}
 sub end_document {
     my $self = shift;
 
@@ -93,7 +84,7 @@ sub on_para {
             $self->mk_end_element( $self->mk_block('itemlist') ) );
         delete $self->{IN_ITEMLIST};
     }
-    return $self->SUPER::on_para( $el, $txt );
+    $txt;
 }
 
 1;
