@@ -1,4 +1,4 @@
-#$Id$
+#$Id: Pod2Events.pm 572 2009-07-07 17:46:25Z zag $
 #
 #  Test blocks events
 package Perl6::Pod::Parser::Pod2Events;
@@ -12,8 +12,8 @@ use base qw/ XML::ExtOn /;
 
 use constant {
     NEW_LINE  => qr/^ \s* $/xms,
-    DIRECTIVE => qr/^(begin|config|encoding|end|for|use|alias)$/xms,
-    BLOCK_NULL_CONTENT => qr/^(config|encoding|use|alias)$/xms,
+    DIRECTIVE => qr/^(begin|config|encoding|end|for|use)$/xms,
+    BLOCK_NULL_CONTENT => qr/^(config|encoding|use)$/xms,
 };
 
 =head2 parse_config_str
@@ -70,7 +70,7 @@ sub stop_config {
     $elem->{NAME} = $name;
     $elem->{OPT} = join " ", @block_opt;
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
-    $parser->start_block( $elem->{NAME}, $elem->{OPT}, $elem->{LINE_NUM}, $elem );
+    $parser->start_block( $elem->{NAME}, $elem->{OPT}, $elem->{LINE_NUM} );
 }
 
 sub on_characters {
@@ -79,13 +79,12 @@ sub on_characters {
     my $text = shift;
     return unless defined $text;
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
-
-#    if ( $text =~ /${\( NEW_LINE )}/ ) {
-#        $self->_flush_para( $elem )
-#    }
-#    else {
+    if ( $text =~ /${\( NEW_LINE )}/ ) {
+        $self->_flush_para( $elem )
+    }
+    else {
         $elem->{TEXT} .= $text;
-#    }
+    }
     return;
 }
 
@@ -93,7 +92,7 @@ sub _flush_para {
     my $self = shift;
     my $elem = shift || return;
     if ( my $agregated = delete $elem->{TEXT} ) {
-        my $parser = $self->{parser} || die '$self->{parser} -> undef !';
+        my $parser = $self->{parser} || die '$self->{parser} - > undef !';
         $parser->para($agregated);
     }
     return
@@ -105,7 +104,6 @@ sub on_end_element {
 
     #flush agregated characters
     $self->_flush_para( $elem);
-
     my $parser = $self->{parser} || die '$self->{parser} - > undef !';
     $parser->end_block( $elem->{NAME}, $elem->{OPT}, $elem->{END_LINE} );
     $elem;
@@ -127,11 +125,11 @@ sub new_line {
             $self->stop_config($el);
 
         }
-#        else {
+        else {
             if ( $el->local_name eq 'begin' ) {
                 $self->characters( { Data => "\n" } );
             }
-#        }
+        }
 
         #skip already stopped
         if ( $el->local_name ne 'begin' ) {
@@ -150,13 +148,12 @@ sub before_start_directive {
     my $str_num = shift;
     if ( my $current = $self->current_element ) {
         $self->stop_config($current);
-        if ( $current->local_name eq 'begin' ) {
-                $self->_flush_para( $current );
-        } else {
+        $self->_flush_para( $current );
+        unless ( $current->local_name eq 'begin' ) {
             $current->{END_LINE} = $str_num;
             $self->end_element($current);
 
-        } 
+        }
     }
 }
 
@@ -199,8 +196,6 @@ sub parse {
                     my $block = $self->mk_element($name);
                     $block->{PARA}     = $_;
                     $block->{LINE_NUM} = $str_num;
-                    #save RAW sting of line
-                    $block->{RAW} .= $_;
 
                     #start element
                     $self->start_element($block);
@@ -232,8 +227,6 @@ sub parse {
 
                         #get config string
                         my $conf = $_;
-                        #save RAW sting of config part
-                        $current->{RAW} .= $conf;
                         $conf =~ s/^=\s+(.*)?/$1/;
                         $self->parse_config_str( $current, $conf );
                     }
@@ -246,17 +239,13 @@ sub parse {
             1;
           }
           || ( !$self->in_ambient_mode ) && do {
-          # close stop
-           my $current = $self->current_element;
-           unless ( $current->{STOP_CONFIG} ) {
-             $self->stop_config($current);
-            }
-           my $lname = $self->current_element->local_name;
-           #check if new line
-            if (/${\( NEW_LINE )}/ && $lname ne 'begin') {
+
+            #check if new line
+            if (/${\( NEW_LINE )}/) {
                 $self->new_line($str_num);
             }
             else {
+                my $lname = $self->current_element->local_name;
                 #for directives use|config|encoding
                 if ($lname =~ /${\( BLOCK_NULL_CONTENT )}/) {
                   $self->before_start_directive(); 
