@@ -1,5 +1,6 @@
 package Test::Filter;
 use strict;
+use warnings;
 use Test::More;
 use XML::ExtOn('create_pipe');
 use base 'XML::ExtOn';
@@ -15,7 +16,7 @@ sub on_start_element {
 
 package Perl6::Pod::To::XHTML;
 
-#$Id$
+#$Id: XHTML.pm 582 2009-07-26 09:04:44Z zag $
 
 =pod
 
@@ -27,18 +28,6 @@ package Perl6::Pod::To::XHTML;
 
     my $p = new Perl6::Pod::To::XHTML:: 
                 header => 0, doctype => 'html';
-fill html head
-    my $p = new Perl6::Pod::To::XHTML:: 
-                header => 1, doctype => 'html',
-                head=>[ 
-                    link=>
-                        {
-                            rel=>"stylesheet",
-                            href=>"/styles/main.1232622176.css"
-                        } 
-                    ],
-               body=>1 #add <body> tag. Default: 0;
-    
 
 =head1 DESCRIPTION
 
@@ -69,13 +58,10 @@ Result xml:
 use strict;
 use warnings;
 use Perl6::Pod::To::XML;
+use XML::SAX::Writer;
 use Perl6::Pod::Parser::ListLevels;
 use Perl6::Pod::Parser::AddHeadLevels;
-use Perl6::Pod::To::XHTML::ProcessHeadings;
-use Perl6::Pod::To::XHTML::MakeHead;
-use Perl6::Pod::To::XHTML::MakeBody;
-use Perl6::Pod::Parser::Doformatted;
-use Perl6::Pod::Parser::NestedAttr;
+use Perl6::Pod::To::XHTML::ProcessHeads;
 use XML::ExtOn('create_pipe');
 use base qw/Perl6::Pod::To::XML/;
 use constant POD_URI => 'http://perlcabal.org/syn/S26.html';
@@ -83,26 +69,13 @@ use Data::Dumper;
 
 sub new {
     my $class = shift;
-    my $self = $class->SUPER::new( body => 0, @_ );
-    if ( my $heads = $self->{head} ) {
-
-        #make head filter
-        my $headfilter = new Perl6::Pod::To::XHTML::MakeHead:: head => $heads;
-        $self->{out_put} = create_pipe( $headfilter, $self->{out_put} );
-
-    }
-    if ( $self->{body} ) {
-
-        #make body
-        my $add_body_filter = new Perl6::Pod::To::XHTML::MakeBody::;
-        $self->{out_put} = create_pipe( $add_body_filter, $self->{out_put} );
-    }
+    my $self  = $class->SUPER::new(@_);
     $self->{out_put} =
-      create_pipe( 'Perl6::Pod::To::XHTML::ProcessHeadings', $self->{out_put} );
+      create_pipe( 'Perl6::Pod::To::XHTML::ProcessHeads', $self->{out_put} );
     return create_pipe(
-        'Perl6::Pod::Parser::NestedAttr', 'Perl6::Pod::Parser::Doformatted',
-        'Perl6::Pod::Parser::ListLevels', 'Perl6::Pod::Parser::AddHeadLevels',
-        'Test::Filter',                   $self
+        'Perl6::Pod::Parser::ListLevels',
+        'Perl6::Pod::Parser::AddHeadLevels',
+        'Test::Filter', $self
     );
 }
 
@@ -115,21 +88,20 @@ sub start_document {
                 {
                     Name => $self->{doctype} || 'html',
                     PublicId => "-//W3C//DTD XHTML 1.1//EN",
-                    SystemId => "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"
+                    SystemId =>"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"
                 }
             );
             $out->end_dtd;
         }
         my $root = $out->mk_element( $self->{doctype} || 'html' );
-        $out->on_start_prefix_mapping( '' => "http://www.w3.org/1999/xhtml" );
+        $out->on_start_prefix_mapping( ''=>"http://www.w3.org/1999/xhtml");
         $out->start_element($root);
     }
 }
 
 sub end_document {
-    my $self = shift;
-    if ( my $out = $self->out_parser ) {
-        my $root = $out->mk_element( $self->{doctype} || 'html' );
+    if ( my $out = $_[0]->out_parser ) {
+        my $root = $out->mk_element( $_[0]->{doctype} || 'html' );
         $out->end_element($root);
         $out->end_document;
     }
@@ -188,10 +160,7 @@ sub print_export {
     my $self = shift;
     for (@_) {
         my @data = ref($_) eq 'ARRAY' ? @{$_} : $_;
-        foreach my $el (@data) {
-            $el = $self->mk_characters($el) unless ref $el;
-            $self->out_parser->_process_comm($el);
-        }
+        $self->out_parser->_process_comm($_) for @data;
     }
 }
 
@@ -208,7 +177,7 @@ sub on_end_block {
     return $el unless $el->isa('Perl6::Pod::Block');
     my $content = exists $el->{_CONTENT_} ? $el->{_CONTENT_} : undef;
     my $data = $self->__handle_export( $el, @$content );
-    my $cel = $self->current_root_element;
+    my $cel = $self->current_element;
     if ($cel) {
         push @{ $cel->{_CONTENT_} }, ref($data) eq 'ARRAY' ? @$data : $data;
         return;
@@ -220,116 +189,67 @@ sub on_end_block {
     return $el;
 }
 
-sub _make_events {
-    my $self = shift;
-    my @in   = $self->__expand_array_ref(@_);
-    my @out  = ();
-    foreach my $elem (@in) {
-        push @out, ref($elem)
-          ? $elem
-          : $self->mk_characters( $self->_html_escape($elem) );
-    }
-    return @out;
-}
-
-sub export_block__DEFN_TERM_ {
+sub export_block_item {
     my ( $self, $el, @p ) = @_;
+    my $elem =
+      $self->mk_element('listitem')
+      ->add_content($self->mk_characters(@p)  );
 
-    return $self->mk_element('strong')->add_content( $self->_make_events(@p) )
-      ->insert_to( $self->mk_element('dt') );
+    #add POD attr for use in export_block_itemlist
+    #for varlistentry
+    $elem->{POD} = $el->get_attr;
+    return $elem;
 }
 
-# <item> - $self->current_root_element
-#  <_ITEM_ENTRY_>
-#       ...
-#  </_ITEM_ENTRY_>
-# </item>
-sub export_block__ITEM_ENTRY_ {
+sub export_block_itemlist {
     my ( $self, $el, @p ) = @_;
     my $attr = $el->attrs_by_name;
     my ( $list_name, $items_name ) = @{
         {
-            ordered    => [ 'ol', 'li' ],
+            ordered    => [ 'ol',  'li' ],
             unordered  => [ 'ul', 'li' ],
             definition => [ 'dl', 'dd' ]
         }->{ $attr->{listtype} }
       };
-    my $list =
-      $self->mk_element($items_name)->add_content( $self->_make_events(@p) );
-    #check if numbered item
-    my $item_attr = $el->attrs_by_name;
-    if ( my $number =  $item_attr->{number_value}) {
-        my $value = $item_attr->{number_value};
-       $list->attrs_by_name->{value} = $value; 
-    }
-    return $list;
+    my $list = $self->mk_element($list_name);
+    foreach (@p) {
+        next unless ref $_;
+        my $lname = $_->local_name;
+        if ( $lname eq 'listitem' ) {
+            $_->local_name($items_name);
 
-}
+            #if variable list, then add varlistentry
+            if ( $list->local_name eq 'dl' ) {
+                my ($term) = @{ $_->{POD}->{term} };
 
-sub export_block__LIST_ITEM_ {
-    my ( $self, $el, @p ) = @_;
+                my $var_entry =
+                  $self->mk_element('dt')
+                  ->add_content( $self->mk_element('strong')
+                      ->add_content( $self->mk_characters($term) ) );
+                $var_entry->add_content($_);
+                $list->add_content($var_entry);
+
+            }
+            else {
+                $list->add_content($_);
+            }
 
-    #check type of list
-    my $attr = $el->attrs_by_name;
-    my ( $list_name, $items_name ) = @{
-        {
-            ordered    => [ 'ol', 'li' ],
-            unordered  => [ 'ul', 'li' ],
-            definition => [ 'dl', 'dd' ]
-        }->{ $attr->{listtype} }
-      };
-    my $res =
-      $self->mk_element($list_name)->add_content( $self->_make_events(@p) );
-    #do nesting
-    my $item_level = $el->attrs_by_name->{item_level} || 1;
-    if ( my $count = $item_level -1 ) {
-        for (1..$count) {
-            my $nest =  $self->mk_element('blockquote');
-            $res = $nest->add_content( $res);
         }
     }
 
-    return $res;
+    return $list;
 }
 
 sub export_block_NAME {
     my ( $self, $el, $text ) = @_;
-    my $head =
-      $self->mk_element('head')
-      ->add_content(
-        $self->mk_element('title')->add_content( $self->mk_characters($text) )
-      );
-
+    my $head = $self->mk_element('head')->add_content( 
+    $self->mk_element('title')
+      ->add_content( $self->mk_characters($text) ));
     #mark element as XHTML head
     $head->{XHTML_HEAD}++;
     return $head;
 }
 
-#process N footnote
-sub export_block__NOTES_ {
-    my ( $self, $el, @p ) = @_;
-    my $div = $self->mk_element('div');
-    $div->attrs_by_name->{class} = 'footnote';
-    return $div->add_content(
-        $self->mk_element('p')->add_content( $self->mk_characters("NOTES") ),
-        $self->_make_events(@p) );
-
-}
-
-sub export_block__NOTE_ {
-    my ( $self, $el, @p ) = @_;
-    my $nid = $el->attrs_by_name->{note_id};
-    my $a   = $self->mk_element('a');
-    $a->attrs_by_name->{name} = "ftn.nid${nid}";
-    $a->attrs_by_name->{href} = "#nid${nid}";
-    $a->add_content(
-        $self->mk_element('sup')->add_content( $self->mk_characters("$nid.") )
-    );
-    return $self->mk_element('p')
-      ->add_content( $a, $self->_make_events( " ", @p ) );
-
-}
-
 1;
 __END__
 
@@ -352,4 +272,3 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 
-
